@@ -31,7 +31,8 @@ class InstallerGUI(Frame):
 		self.installed = False
 
 		if to_dl != "":
-			self.installer = Installer(to_dl, self)
+			self.filename = checkname.return_filename(to_dl)
+			self.installer = Installer(to_dl, self, self.filename)
 		else:
 			raise FileURLException("empty URL")
 
@@ -41,8 +42,6 @@ class InstallerGUI(Frame):
 
 		self.to_dl = to_dl
 
-		print(checkname.return_filename(to_dl))
-
 	def initUI(self):
 		self.master.title("InstallerApp")
 		self.style = Style()
@@ -86,7 +85,7 @@ class InstallerGUI(Frame):
 
 
 class Installer(object):
-	def __init__(self, url, master):
+	def __init__(self, url, master, filename):
 		self.url = url
 		self.master = master
 
@@ -95,7 +94,7 @@ class Installer(object):
 
 	def install(self):
 		u = urllib2.urlopen(self.url)
-		f = open("installed.zip", 'wb')
+		f = open(filename, 'wb')
 		file_size = int(u.getheader('Content-Length'))
 		file_size_dl = 0
 		block_sz = 8192
@@ -114,8 +113,8 @@ class Installer(object):
 
 	def unzip(self):
 		try:
-			with zipfile.ZipFile("installed.zip", 'r') as zip_ref:
-			    zip_ref.extractall("Installed")
+			with zipfile.ZipFile(filename, 'r') as zip_ref:
+			    zip_ref.extractall(checkname.return_filename_without_format(filename))
 			    zip_ref.close()
 
 			    self.master.waitingText['text'] = "Extracting..."
@@ -131,13 +130,13 @@ class Installer(object):
 			self.unzip()
 
 	def rmvFiles(self):
-		os.remove("installed.zip")
+		os.remove(filename)
 
 		for i in range(26):
 			self.master.progressBar['value'] = 75 + i
 			time.sleep(0.01)
 
-		self.master.waitingText['text'] = "Installed with 0 errors"
+		self.master.waitingText['text'] = "Installed " + filename + " with 0 errors"
 
 		self.master.installBtn['state'] = NORMAL
 		self.master.installBtn['text'] = "Quit"
